/***********************************************************************************************************************
 *
 * blueBill Mobile - open source birdwatching
 * ==========================================
 *
 * Copyright (C) 2009, 2010 by Tidalwave s.a.s. (http://www.tidalwave.it)
 * http://bluebill.tidalwave.it/mobile/
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * $Id: MultiLanguageDisplayNameInitializer.java,v 7b7cb64fd030 2010/08/12 18:27:07 fabrizio $
 *
 **********************************************************************************************************************/
package it.tidalwave.bluebill.taxonomy.birds;

import it.tidalwave.bluebill.taxonomy.TaxonomyConcept;
import it.tidalwave.openrdf.elmo.RDFUtils;
import it.tidalwave.util.Initializer;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;
import java.util.Map.Entry;
import javax.annotation.Nonnull;
import org.openrdf.elmo.Entity;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id: $
 *
 **********************************************************************************************************************/
public class MultiLanguageDisplayNameInitializer implements Initializer<TaxonomyConcept>
  {
    @Nonnull
    private final Map<Locale, String> languageMapByLocale = new HashMap<Locale, String>();

    public MultiLanguageDisplayNameInitializer (final @Nonnull String ... info)
      {
        for (int i = 0; i < info.length; i += 2)
          {
            languageMapByLocale.put(new Locale(info[i]), info[i + 1]);
          }
      }

    @Nonnull
    public TaxonomyConcept initialize (final @Nonnull TaxonomyConcept taxon)
      {
        for (final Entry<Locale, String> entry : languageMapByLocale.entrySet())
          {
            RDFUtils.setDisplayName(taxon.as(Entity.class), entry.getValue(), entry.getKey());
          }

        return taxon;
      }
  }
